@@ -49,16 +49,14 @@ def static_vars(**kwargs):
 
 class S:
     """
-    A somewhat cryptically named class that keeps system state.
-
-    Calls to the HTTPServer re-initialize the StoreHandler class -- this
+    A somewhat cryptically named class that keeps system state between
+    separate modules/classes. This class was designed to keep object
+    state even if instances of this object class are re-constructed --
+    this typically occurs with certain modules such as the HTTPserver.
+    Each call to the module re-initializes the StoreHandler class, which
     effectively means any per-instance state information is lost across
     calls.
 
-    Barring the use of a module-wide global variable, this class keeps
-    state information as a class (not instance)-variable -- which
-    effectively is analogous to a namespaced global variable.
-
     State-related class variables can thus be accessed by calling the
     class directly, 'S'. For example, to change values in the state
     tree structure, simply call 'S.T.<method>'.
@@ -71,19 +69,35 @@ class S:
     T       = C_stree()
     b_init  = False
 
+    def __call__(self, *args):
+        """
+        set/get components of the state object
+        """
+        if len(args) == 1:
+            return S.T.cat(args[0])
+        else:
+            S.T.touch(args[0], args[1])
+
     def state_create(self, d_state, *args, **kwargs):
         """
         Create the internal object with specific state
         dictionary information.
         """
+
+        for k,v in kwargs.items():
+            if k == 'reinitialize': S.b_init    = v
         S.__init__(self, *args, **kwargs)
         if not S.b_init:
             S.d_state.update(d_state)
             S.T.initFromDict(S.d_state)
             S.b_init    = True
-            if len(S.T.cat('/this/debugToDir')):
-                if not os.path.exists(S.T.cat('/this/debugToDir')):
-                    os.makedirs(S.T.cat('/this/debugToDir'))
+            if len(self('/this/debugToDir')):
+                if not os.path.exists(self('/this/debugToDir')):
+                    os.makedirs(self('/this/debugToDir'))
+            self.dp     = pfmisc.debug(
+                            verbosity   = self('/this/verbosity'),
+                            within      = self('/this/within')
+            )
 
         self.dp.qprint(
             Colors.YELLOW + "\n\t\tInternal data tree:",
@@ -134,18 +148,20 @@ class S:
                     'args':                 d_args
                 }
             }
+            S.T.initFromDict(S.d_state)
 
     def __init__(self, *args, **kwargs):
         """
-        The logic of this constructor reflects a bit from legacy design
-        patterns of `pfcon` -- specifically the passing of flags in a
-        single structure, and the <self.state> dictionary to try and
-        organize the space of <self> variables a bit logically.
+        Constructor. If the object has already been initialized by a subclass
+        with a call to state_create(), then repeated calls of this constructor
+        will not change object state values.
         """
 
-        d_args                  = {}
-        str_desc                = ''
-        str_version             = ''
+        d_args          : dict  = {}
+        str_desc        : str   = ''
+        str_version     : str   = ''
+        verbosity       : int   = 0
+        str_within      : str   = ''
 
         # pudb.set_trace()
 
@@ -158,11 +174,14 @@ class S:
         if not S.b_init:
             self.state_init(d_args, str_name, str_desc, str_version)
 
-        self.dp                 = pfmisc.debug(
-                                    verbosity   = S.T.cat('/this/verbosity'),
-                                    within      = S.T.cat('/this/name')
-                                  )
-        self.pp                 = pprint.PrettyPrinter(indent=4)
+        if not self('/this/verbosity'):  verbosity   = 0
+        else: verbosity     = self('/this/verbosity')
+        if not self('/this/name'):       str_within  = 'pfstate'
+        else: str_within    = self('/this/name')
+        self.dp             = pfmisc.debug(
+                                verbosity   = verbosity,
+                                within      = str_within
+        )
 
     def leaf_process(self, **kwargs):
         """
